Crate api_builder

Crate api_builder 

Re-exports

pub use serde_json;
pub use client::*;
pub use combinators::*;
pub use error::*;
pub use endpoint::*;
pub use macros::*;
pub use query_params::*;
pub use query::*;

Modules

client
combinators
endpoint
error
macros
query
query_params

Macros

headermap
A macro that is similar to vec! but for http::HeaderMaps. This does not check for invalid headers.
headermap_checked
A macro that is similar to vec! but for http::HeaderMaps. This does check for invalid headers.
impl_query
A helper trait for implementing Query for sync clients.
impl_query_async
A helper trait for implementing AsyncQuery for async clients.

Structs

Bytes
A cheaply cloneable and sliceable chunk of contiguous memory.
HeaderMap
A specialized multimap for header names and values.
Method
The Request Method (VERB)
Request
Represents an HTTP request.
RequestBuilder
An HTTP request builder
Response
Represents an HTTP response
StatusCode
An HTTP status code (status-code in RFC 9110 et al.).
Url
A parsed URL record.

Attribute Macros

api_endpoint
Add some methods to your impl block.
api_rest_client
Implements RestClient.

Derive Macros

ReqwestAsyncClient
Implements ReqwestAsyncClient, assumes that the struct has a async_client field.
ReqwestClient
Implements ReqwestClient, assumes that the struct has a client field.