Re-exports
pub use serde_json;pub use client::*;pub use combinators::*;pub use error::*;pub use endpoint::*;pub use macros::*;pub use query_params::*;pub use query::*;
Modules
Macros
- headermap
- A macro that is similar to vec! but for http::HeaderMaps. This does not check for invalid headers.
- headermap_
checked - A macro that is similar to vec! but for http::HeaderMaps. This does check for invalid headers.
- impl_
query - A helper trait for implementing Query for sync clients.
- impl_
query_ async - A helper trait for implementing AsyncQuery for async clients.
Structs
- Bytes
- A cheaply cloneable and sliceable chunk of contiguous memory.
- Header
Map - A specialized multimap for header names and values.
- Method
- The Request Method (VERB)
- Request
- Represents an HTTP request.
- Request
Builder - An HTTP request builder
- Response
- Represents an HTTP response
- Status
Code - An HTTP status code (
status-codein RFC 9110 et al.). - Url
- A parsed URL record.
Attribute Macros
- api_
endpoint - Add some methods to your impl block.
- api_
rest_ client - Implements
RestClient.
Derive Macros
- Reqwest
Async Client - Implements
ReqwestAsyncClient, assumes that the struct has aasync_clientfield. - Reqwest
Client - Implements
ReqwestClient, assumes that the struct has aclientfield.